@@ -180,6 +180,7 @@ standardize_ver <- function(ver, strict = FALSE, complete = TRUE) {
     if (is.numeric(ver)) {
         int <- (!is.na(ver)) & (is.integer(ver) | (is.numeric(ver) & (ver == trunc(ver))))
         if (any(int)) ver[int] <- paste0(ver[int], ".0")
+        ver <- as.character(ver)
     }
 
     if (!inherits(ver, "numeric_version")) ver <- numeric_version(ver, strict = FALSE)
@@ -201,7 +202,7 @@ standardize_ver <- function(ver, strict = FALSE, complete = TRUE) {
 match_minor_ver <- function(ver, all_ver, type = c("idd", "eplus"), max = TRUE, verbose = TRUE) {
     checkmate::assert_class(ver, "numeric_version")
     checkmate::assert_vector(ver, len = 1L)
-    if (!length(all_ver)) return(numeric_version(NA, strict = FALSE))
+    if (!length(all_ver)) return(numeric_version(NA_character_, strict = FALSE))
     all_ver <- unique(all_ver)
     ori_ver <- ver
 
@@ -212,7 +213,7 @@ match_minor_ver <- function(ver, all_ver, type = c("idd", "eplus"), max = TRUE,
     }
 
     if (!length(ver)) {
-        ver <- numeric_version(NA, strict = FALSE)
+        ver <- numeric_version(NA_character_, strict = FALSE)
     } else if (length(ver) > 1L) {
         if (max) {
             ver <- max(ver)
