@@ -1,4 +1,4 @@
-copy_example <- function (ver = 8.8) {
+copy_example <- function(ver = LATEST_EPLUS_VER) {
     if (!is_avail_eplus(ver)) return()
 
     cfg <- eplus_config(ver)
@@ -31,6 +31,6 @@ copy_eplus_example <- function(ver, file, dir = tempdir()) {
     dest
 }
 
-clean_tempdir <- function () {
+clean_tempdir <- function() {
     unlink(list.files(tempdir(), full.names = TRUE), force = TRUE)
 }
